# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from nedo_vision_training.protos import TrainingJobService_pb2 as nedo__vision__training_dot_protos_dot_TrainingJobService__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in nedo_vision_training/protos/TrainingJobService_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class TrainingJobServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateStatusLog = channel.unary_unary(
                '/Sindika.AspNet.App005.Services.TrainingJobService/CreateStatusLog',
                request_serializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.CreateStatusLogRequest.SerializeToString,
                response_deserializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.CreateStatusLogResponse.FromString,
                _registered_method=True)
        self.CreateCommandLog = channel.unary_unary(
                '/Sindika.AspNet.App005.Services.TrainingJobService/CreateCommandLog',
                request_serializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.CreateCommandLogRequest.SerializeToString,
                response_deserializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.CreateCommandLogResponse.FromString,
                _registered_method=True)
        self.CreateMetricsLog = channel.unary_unary(
                '/Sindika.AspNet.App005.Services.TrainingJobService/CreateMetricsLog',
                request_serializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.CreateMetricsLogRequest.SerializeToString,
                response_deserializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.CreateMetricsLogResponse.FromString,
                _registered_method=True)
        self.UpdateModelFilePath = channel.unary_unary(
                '/Sindika.AspNet.App005.Services.TrainingJobService/UpdateModelFilePath',
                request_serializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.UpdateModelFilePathRequest.SerializeToString,
                response_deserializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.UpdateModelFilePathResponse.FromString,
                _registered_method=True)
        self.UploadModel = channel.stream_unary(
                '/Sindika.AspNet.App005.Services.TrainingJobService/UploadModel',
                request_serializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.UploadModelRequest.SerializeToString,
                response_deserializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.UploadModelResponse.FromString,
                _registered_method=True)


class TrainingJobServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateStatusLog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateCommandLog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateMetricsLog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateModelFilePath(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadModel(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TrainingJobServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateStatusLog': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateStatusLog,
                    request_deserializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.CreateStatusLogRequest.FromString,
                    response_serializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.CreateStatusLogResponse.SerializeToString,
            ),
            'CreateCommandLog': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCommandLog,
                    request_deserializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.CreateCommandLogRequest.FromString,
                    response_serializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.CreateCommandLogResponse.SerializeToString,
            ),
            'CreateMetricsLog': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMetricsLog,
                    request_deserializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.CreateMetricsLogRequest.FromString,
                    response_serializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.CreateMetricsLogResponse.SerializeToString,
            ),
            'UpdateModelFilePath': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateModelFilePath,
                    request_deserializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.UpdateModelFilePathRequest.FromString,
                    response_serializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.UpdateModelFilePathResponse.SerializeToString,
            ),
            'UploadModel': grpc.stream_unary_rpc_method_handler(
                    servicer.UploadModel,
                    request_deserializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.UploadModelRequest.FromString,
                    response_serializer=nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.UploadModelResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Sindika.AspNet.App005.Services.TrainingJobService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('Sindika.AspNet.App005.Services.TrainingJobService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class TrainingJobService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateStatusLog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Sindika.AspNet.App005.Services.TrainingJobService/CreateStatusLog',
            nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.CreateStatusLogRequest.SerializeToString,
            nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.CreateStatusLogResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateCommandLog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Sindika.AspNet.App005.Services.TrainingJobService/CreateCommandLog',
            nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.CreateCommandLogRequest.SerializeToString,
            nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.CreateCommandLogResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateMetricsLog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Sindika.AspNet.App005.Services.TrainingJobService/CreateMetricsLog',
            nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.CreateMetricsLogRequest.SerializeToString,
            nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.CreateMetricsLogResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateModelFilePath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Sindika.AspNet.App005.Services.TrainingJobService/UpdateModelFilePath',
            nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.UpdateModelFilePathRequest.SerializeToString,
            nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.UpdateModelFilePathResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UploadModel(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/Sindika.AspNet.App005.Services.TrainingJobService/UploadModel',
            nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.UploadModelRequest.SerializeToString,
            nedo__vision__training_dot_protos_dot_TrainingJobService__pb2.UploadModelResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
